@@ -39,6 +39,7 @@ from beeswarm.server.db.entities import Client, BaitSession, Session, Honeypot,
     Authentication
 from beeswarm.shared.helpers import send_zmq_request_socket
 from beeswarm.shared.message_enum import Messages
+from beeswarm.shared.socket_enum import SocketNames
 import beeswarm
 
 
@@ -66,7 +67,7 @@ drone_keys = []
 
 context = beeswarm.shared.zmq_context
 config_actor_socket = context.socket(zmq.REQ)
-config_actor_socket.connect('inproc://configCommands')
+config_actor_socket.connect(SocketNames.CONFIG_COMMANDS)
 request_lock = gevent.lock.RLock()
 
 
@@ -501,9 +502,7 @@ def data_session_credentials(_id):
     credentials = db_session.query(Authentication).filter(Authentication.session_id == _id)
     return_rows = []
     for c in credentials:
-        return_rows.append({'username': c.username,
-                            'password': c.password,
-                            'successful': c.successful})
+        return_rows.append(c.to_dict())
     rsp = Response(response=json.dumps(return_rows, indent=4), status=200, mimetype='application/json')
     return rsp
 
